2.0.0
=====

Switch to pkgutil-style namespace.

1.5.0
=====

Pin dependencies for namespace compatibility.

1.1.0
=====

Moved project to Github.

Incorporated `project
skeleton from jaraco <https://github.com/jaraco/skeleton>`_.

Enabled automatic releases of tagged commits.

1.0
===

Various module refactorings.
